@@ -6,13 +6,15 @@
  *	Copyright (c) 2003-2009, PostgreSQL Global Development Group
  *	Author: Jan Wieck, Afilias USA INC.
  *
- *	
+ *	$Id: slony1_funcs.c,v 1.68.2.5 2010-02-16 16:57:48 cbbrowne Exp $
  * ----------------------------------------------------------------------
  */
 
 #include "postgres.h"
 #include "config.h"
 
+#include "avl_tree.c"
+
 #include "miscadmin.h"
 #include "nodes/makefuncs.h"
 #include "parser/keywords.h"
@@ -39,26 +41,23 @@
 
 #include <signal.h>
 #include <errno.h>
+/*@+matchanyintegral@*/
+/*@-compmempass@*/
+/*@-immediatetrans@*/
 
 #ifdef PG_MODULE_MAGIC
 PG_MODULE_MAGIC;
 #endif
 
-/* -- Change from PostgreSQL Ver 8.3 -- */
-#if !((PG_VERSION_MAJOR > 8) || ((PG_VERSION_MAJOR == 8) && (PG_VERSION_MINOR >= 3)))
-#define SET_VARSIZE(datum, size) (VARATT_SIZEP(datum)=(size))
-#endif
-
 PG_FUNCTION_INFO_V1(_Slony_I_createEvent);
 PG_FUNCTION_INFO_V1(_Slony_I_getLocalNodeId);
 PG_FUNCTION_INFO_V1(_Slony_I_getModuleVersion);
 
-PG_FUNCTION_INFO_V1(_Slony_I_setSessionRole);
-PG_FUNCTION_INFO_V1(_Slony_I_getSessionRole);
 PG_FUNCTION_INFO_V1(_Slony_I_logTrigger);
 PG_FUNCTION_INFO_V1(_Slony_I_denyAccess);
 PG_FUNCTION_INFO_V1(_Slony_I_lockedSet);
 PG_FUNCTION_INFO_V1(_Slony_I_killBackend);
+PG_FUNCTION_INFO_V1(_Slony_I_seqtrack);
 
 PG_FUNCTION_INFO_V1(_slon_quote_ident);
 
@@ -67,30 +66,22 @@ Datum		_Slony_I_createEvent(PG_FUNCTION_ARGS);
 Datum		_Slony_I_getLocalNodeId(PG_FUNCTION_ARGS);
 Datum		_Slony_I_getModuleVersion(PG_FUNCTION_ARGS);
 
-Datum		_Slony_I_setSessionRole(PG_FUNCTION_ARGS);
-Datum		_Slony_I_getSessionRole(PG_FUNCTION_ARGS);
 Datum		_Slony_I_logTrigger(PG_FUNCTION_ARGS);
 Datum		_Slony_I_denyAccess(PG_FUNCTION_ARGS);
 Datum		_Slony_I_lockedSet(PG_FUNCTION_ARGS);
 Datum		_Slony_I_killBackend(PG_FUNCTION_ARGS);
+Datum		_Slony_I_seqtrack(PG_FUNCTION_ARGS);
 
 Datum		_slon_quote_ident(PG_FUNCTION_ARGS);
 
-
 #ifdef CYGWIN
 extern DLLIMPORT Node *newNodeMacroHolder;
 #endif
 
 #define PLAN_NONE			0
-#define PLAN_NOTIFY_EVENT	(1 << 0)
 #define PLAN_INSERT_EVENT	(1 << 1)
 #define PLAN_INSERT_LOG		(1 << 2)
 
-#define SLON_ROLE_UNSET		0
-#define SLON_ROLE_NORMAL	1
-#define SLON_ROLE_SLON		2
-
-
 
 /* ----
  * Slony_I_ClusterStatus -
@@ -104,11 +95,9 @@ typedef struct slony_I_cluster_status
 	char	   *clusterident;
 	int32		localNodeId;
 	TransactionId currentXid;
-	int			session_role;
 	void	   *plan_active_log;
 
 	int			have_plan;
-	void	   *plan_notify_event;
 	void	   *plan_insert_event;
 	void	   *plan_insert_log_1;
 	void	   *plan_insert_log_2;
@@ -123,14 +112,14 @@ typedef struct slony_I_cluster_status
 	int			cmddata_size;
 
 	struct slony_I_cluster_status *next;
-}	Slony_I_ClusterStatus;
-
+} Slony_I_ClusterStatus;
 
+/*@null@*/
 static Slony_I_ClusterStatus *clusterStatusList = NULL;
 static Slony_I_ClusterStatus *
 getClusterStatus(Name cluster_name,
 				 int need_plan_mask);
-const char *slon_quote_identifier(const char *ident);
+static const char *slon_quote_identifier(const char *ident);
 static char *slon_quote_literal(char *str);
 
 
@@ -139,24 +128,23 @@ _Slony_I_createEvent(PG_FUNCTION_ARGS)
 {
 	TransactionId newXid = GetTopTransactionId();
 	Slony_I_ClusterStatus *cs;
-	text	   *ev_xip;
 	char	   *ev_type_c;
-	Datum		argv[12];
-	char		nulls[13];
+	Datum		argv[9];
+	char		nulls[10];
 	char	   *buf;
 	size_t		buf_size;
 	int			rc;
-	int			xcnt;
-	char	   *cp;
 	int			i;
 	int64		retval;
 	bool		isnull;
-#ifdef HAVE_GETACTIVESNAPSHOT
-	Snapshot	SerializableSnapshot = GetActiveSnapshot();
-#endif
 
+#ifdef HAVE_GETACTIVESNAPSHOT
+	if (GetActiveSnapshot() == NULL)
+		elog(ERROR, "Slony-I: ActiveSnapshot is NULL in createEvent()");
+#else
 	if (SerializableSnapshot == NULL)
 		elog(ERROR, "Slony-I: SerializableSnapshot is NULL in createEvent()");
+#endif
 
 	if ((rc = SPI_connect()) < 0)
 		elog(ERROR, "Slony-I: SPI_connect() failed in createEvent()");
@@ -166,7 +154,7 @@ _Slony_I_createEvent(PG_FUNCTION_ARGS)
 	 * SPI plans that we need here.
 	 */
 	cs = getClusterStatus(PG_GETARG_NAME(0),
-						  PLAN_NOTIFY_EVENT | PLAN_INSERT_EVENT);
+						  PLAN_INSERT_EVENT);
 
 	buf_size = 8192;
 	buf = palloc(buf_size);
@@ -176,57 +164,26 @@ _Slony_I_createEvent(PG_FUNCTION_ARGS)
 	 */
 	if (!TransactionIdEquals(cs->currentXid, newXid))
 	{
-		/*
-		 * Once per transaction notify on the sl_event relation
-		 */
-		if ((rc = SPI_execp(cs->plan_notify_event, NULL, NULL, 0)) < 0)
-			elog(ERROR, "Slony-I: SPI_execp() failed for \"NOTIFY event\"");
-
 		cs->currentXid = newXid;
 	}
 
-	/*
-	 * Build the comma separated list of transactions in progress as Text
-	 * datum.
-	 */
-	*(cp = buf) = '\0';
-	for (xcnt = 0; xcnt < SerializableSnapshot->xcnt; xcnt++)
-	{
-		if ((cp + 30) >= (buf + buf_size))
-		{
-			buf_size *= 2;
-			buf = repalloc(buf, buf_size);
-			cp = buf + strlen(buf);
-		}
-		sprintf(cp, "%s'%u'", (xcnt > 0) ? "," : "",
-				SerializableSnapshot->xip[xcnt]);
-		cp += strlen(cp);
-	}
-	ev_xip = DatumGetTextP(DirectFunctionCall1(textin, PointerGetDatum(buf)));
-
 	/*
 	 * Call the saved INSERT plan
 	 */
-	argv[0] = TransactionIdGetDatum(SerializableSnapshot->xmin);
-	argv[1] = TransactionIdGetDatum(SerializableSnapshot->xmax);
-	argv[2] = PointerGetDatum(ev_xip);
-	nulls[0] = ' ';
-	nulls[1] = ' ';
-	nulls[2] = ' ';
 	for (i = 1; i < 10; i++)
 	{
 		if (i >= PG_NARGS() || PG_ARGISNULL(i))
 		{
-			argv[i + 2] = (Datum)0;
-			nulls[i + 2] = 'n';
+			argv[i - 1] = (Datum) 0;
+			nulls[i - 1] = 'n';
 		}
 		else
 		{
-			argv[i + 2] = PG_GETARG_DATUM(i);
-			nulls[i + 2] = ' ';
+			argv[i - 1] = PG_GETARG_DATUM(i);
+			nulls[i - 1] = ' ';
 		}
 	}
-	nulls[12] = '\0';
+	nulls[9] = '\0';
 
 	if ((rc = SPI_execp(cs->plan_insert_event, argv, nulls, 0)) < 0)
 		elog(ERROR, "Slony-I: SPI_execp() failed for \"INSERT INTO sl_event ...\"");
@@ -251,16 +208,20 @@ _Slony_I_createEvent(PG_FUNCTION_ARGS)
 		if (strcmp(ev_type_c, "SYNC") == 0 ||
 			strcmp(ev_type_c, "ENABLE_SUBSCRIPTION") == 0)
 		{
+/*@-nullpass@*/
 			if ((rc = SPI_execp(cs->plan_record_sequences, NULL, NULL, 0)) < 0)
 				elog(ERROR, "Slony-I: SPI_execp() failed for \"INSERT INTO sl_seqlog ...\"");
+/*@+nullpass@*/
 		}
 	}
 
-	SPI_finish();
-
+	(void) SPI_finish();
+/*@-mustfreefresh@*/
 	PG_RETURN_INT64(retval);
 }
 
+/*@+mustfreefresh@*/
+
 
 /*
  * _Slony_I_getLocalNodeId -
@@ -303,100 +264,13 @@ _Slony_I_getModuleVersion(PG_FUNCTION_ARGS)
 	len = strlen(SLONY_I_VERSION_STRING);
 	retval = palloc(VARHDRSZ + len);
 
-        SET_VARSIZE(retval,VARHDRSZ + len);
+	SET_VARSIZE(retval, VARHDRSZ + len);
 	memcpy(VARDATA(retval), SLONY_I_VERSION_STRING, len);
 
 	PG_RETURN_TEXT_P(retval);
 }
 
 
-Datum
-_Slony_I_setSessionRole(PG_FUNCTION_ARGS)
-{
-	Slony_I_ClusterStatus *cs;
-	int			rc;
-	text	   *new_role_t = PG_GETARG_TEXT_P(1);
-	int			new_role = SLON_ROLE_UNSET;
-
-	if ((rc = SPI_connect()) < 0)
-		elog(ERROR, "Slony-I: SPI_connect() failed in setSessionRole()");
-
-	cs = getClusterStatus(PG_GETARG_NAME(0), PLAN_NONE);
-
-	SPI_finish();
-
-	if (VARSIZE(new_role_t) == VARHDRSZ + 6 &&
-		memcmp(VARDATA(new_role_t), "normal", 6) == 0)
-	{
-		new_role = SLON_ROLE_NORMAL;
-	}
-	else if (VARSIZE(new_role_t) == VARHDRSZ + 4 &&
-			 memcmp(VARDATA(new_role_t), "slon", 4) == 0)
-	{
-		if (!superuser())
-			elog(ERROR, "Slony-I: insufficient privilege for replication role");
-
-		new_role = SLON_ROLE_SLON;
-	}
-	else
-	{
-		elog(ERROR, "Slony-I: invalid session role");
-	}
-
-	if (cs->session_role == SLON_ROLE_UNSET ||
-		cs->session_role == new_role)
-	{
-		cs->session_role = new_role;
-	}
-	else
-	{
-		elog(ERROR, "Slony-I: cannot change session role once set");
-	}
-
-	PG_RETURN_TEXT_P(new_role_t);
-}
-
-
-Datum
-_Slony_I_getSessionRole(PG_FUNCTION_ARGS)
-{
-	Slony_I_ClusterStatus *cs;
-	int			rc;
-	text	   *retval = NULL;
-
-	if ((rc = SPI_connect()) < 0)
-		elog(ERROR, "Slony-I: SPI_connect() failed in getSessionRole()");
-
-	cs = getClusterStatus(PG_GETARG_NAME(0), PLAN_NONE);
-
-	SPI_finish();
-
-	switch (cs->session_role)
-	{
-		case SLON_ROLE_UNSET:
-			cs->session_role = SLON_ROLE_NORMAL;
-			retval = palloc(VARHDRSZ + 6);
-			SET_VARSIZE(retval, VARHDRSZ + 6);
-			memcpy(VARDATA(retval), "normal", 6);
-			break;
-
-		case SLON_ROLE_NORMAL:
-			retval = palloc(VARHDRSZ + 6);
-			SET_VARSIZE(retval, VARHDRSZ + 6);
-			memcpy(VARDATA(retval), "normal", 6);
-			break;
-
-		case SLON_ROLE_SLON:
-			retval = palloc(VARHDRSZ + 4);
-			SET_VARSIZE(retval, VARHDRSZ + 4);
-			memcpy(VARDATA(retval), "slon", 4);
-			break;
-	}
-
-	PG_RETURN_TEXT_P(retval);
-}
-
-
 Datum
 _Slony_I_logTrigger(PG_FUNCTION_ARGS)
 {
@@ -412,6 +286,12 @@ _Slony_I_logTrigger(PG_FUNCTION_ARGS)
 	int			attkind_idx;
 	int			cmddata_need;
 
+	/*
+	 * Don't do any logging if the current session role isn't Origin.
+	 */
+	if (SessionReplicationRole != SESSION_REPLICATION_ROLE_ORIGIN)
+		return PointerGetDatum(NULL);
+
 	/*
 	 * Get the trigger call context
 	 */
@@ -449,58 +329,41 @@ _Slony_I_logTrigger(PG_FUNCTION_ARGS)
 	 */
 	cs = getClusterStatus(cluster_name, PLAN_INSERT_LOG);
 
-	/*
-	 * Check/set the session role
-	 */
-	switch (cs->session_role)
-	{
-		case SLON_ROLE_UNSET:	/* Nobody told us, force it to normal */
-			cs->session_role = SLON_ROLE_NORMAL;
-			break;
-
-		case SLON_ROLE_NORMAL:	/* Normal, that's good */
-			break;
-
-		case SLON_ROLE_SLON:	/* non-client session ??? */
-			/* This would happen when a trigger on a
-			 * subscriber on a replicated table fires, and
-			 * modifies a tuple in a replication set for
-			 * which this node is the origin */
-			break;
-	}
-
 	/*
 	 * Do the following only once per transaction.
 	 */
 	if (!TransactionIdEquals(cs->currentXid, newXid))
 	{
-		int32	log_status;
+		int32		log_status;
 		bool isnull;
 
 		/*
 		 * Determine the currently active log table
 		 */
-		if(SPI_execp(cs->plan_get_logstatus, NULL, NULL, 0) < 0)
+		if (SPI_execp(cs->plan_get_logstatus, NULL, NULL, 0) < 0)
 			elog(ERROR, "Slony-I: cannot determine log status");
 		if (SPI_processed != 1)
 			elog(ERROR, "Slony-I: cannot determine log status");
 
 		log_status = DatumGetInt32(SPI_getbinval(SPI_tuptable->vals[0],
-									SPI_tuptable->tupdesc, 1, &isnull));
+											SPI_tuptable->tupdesc, 1, &isnull));
 		SPI_freetuptable(SPI_tuptable);
 
-		switch(log_status)
+		switch (log_status)
 		{
 			case 0:
-			case 2:		cs->plan_active_log = cs->plan_insert_log_1;
-						break;
-			
-			case 1:
-			case 3:		cs->plan_active_log = cs->plan_insert_log_2;
-						break;
+			case 2:
+				cs->plan_active_log = cs->plan_insert_log_1;
+				break;
 
-			default:	elog(ERROR, "Slony-I: illegal log status %d", log_status);
-						break;
+			case 1:
+			case 3:
+				cs->plan_active_log = cs->plan_insert_log_2;
+				break;
+
+			default:
+				elog(ERROR, "Slony-I: illegal log status %d", log_status);
+				break;
 		}
 
 		cs->currentXid = newXid;
@@ -515,12 +378,12 @@ _Slony_I_logTrigger(PG_FUNCTION_ARGS)
 		TupleDesc	tupdesc = tg->tg_relation->rd_att;
 		char	   *col_ident;
 		char	   *col_value;
-		
+
 		int			len_ident;
 		int			len_value;
 		int			i;
 		int			need_comma = false;
-		char			*OldDateStyle;
+		char	   *OldDateStyle;
 		char	   *cp = VARDATA(cs->cmddata_buf);
 
 		/*
@@ -542,17 +405,17 @@ _Slony_I_logTrigger(PG_FUNCTION_ARGS)
 			if (tupdesc->attrs[i]->attisdropped)
 				continue;
 
-			col_ident = (char *)slon_quote_identifier(SPI_fname(tupdesc, i + 1));
-			cmddata_need = (cp - (char *)(cs->cmddata_buf)) + 16 +
+			col_ident = (char *) slon_quote_identifier(SPI_fname(tupdesc, i + 1));
+			cmddata_need = (cp - (char *) (cs->cmddata_buf)) + 16 +
 				(len_ident = strlen(col_ident));
 			if (cs->cmddata_size < cmddata_need)
 			{
-				int			have = (cp - (char *)(cs->cmddata_buf));
+				int			have = (cp - (char *) (cs->cmddata_buf));
 
 				while (cs->cmddata_size < cmddata_need)
 					cs->cmddata_size *= 2;
 				cs->cmddata_buf = realloc(cs->cmddata_buf, cs->cmddata_size);
-				cp = (char *)(cs->cmddata_buf) + have;
+				cp = (char *) (cs->cmddata_buf) + have;
 			}
 
 			if (need_comma)
@@ -582,8 +445,9 @@ _Slony_I_logTrigger(PG_FUNCTION_ARGS)
 		 * Append the values
 		 */
 		need_comma = false;
-		OldDateStyle=GetConfigOptionByName("DateStyle", NULL);
-		set_config_option("DateStyle", "ISO", PGC_USERSET, PGC_S_SESSION, true, true);
+		OldDateStyle = GetConfigOptionByName("DateStyle", NULL);
+		if (!strstr(OldDateStyle, "ISO"))
+			set_config_option("DateStyle", "ISO", PGC_USERSET, PGC_S_SESSION, true, true);
 		for (i = 0; i < tg->tg_relation->rd_att->natts; i++)
 		{
 			/*
@@ -602,16 +466,16 @@ _Slony_I_logTrigger(PG_FUNCTION_ARGS)
 				col_value = slon_quote_literal(col_value);
 			}
 
-			cmddata_need = (cp - (char *)(cs->cmddata_buf)) + 16 +
+			cmddata_need = (cp - (char *) (cs->cmddata_buf)) + 16 +
 				(len_value = strlen(col_value));
 			if (cs->cmddata_size < cmddata_need)
 			{
-				int			have = (cp - (char *)(cs->cmddata_buf));
+				int			have = (cp - (char *) (cs->cmddata_buf));
 
 				while (cs->cmddata_size < cmddata_need)
 					cs->cmddata_size *= 2;
 				cs->cmddata_buf = realloc(cs->cmddata_buf, cs->cmddata_size);
-				cp = (char *)(cs->cmddata_buf) + have;
+				cp = (char *) (cs->cmddata_buf) + have;
 			}
 
 			if (need_comma)
@@ -623,15 +487,16 @@ _Slony_I_logTrigger(PG_FUNCTION_ARGS)
 			cp += len_value;
 		}
 
-		set_config_option("DateStyle", OldDateStyle, PGC_USERSET, PGC_S_SESSION, true, true);
+		if (!strstr(OldDateStyle, "ISO"))
+			set_config_option("DateStyle", OldDateStyle, PGC_USERSET, PGC_S_SESSION, true, true);
 
 		/*
 		 * Terminate and done
 		 */
 		*cp++ = ')';
 		*cp = '\0';
-		SET_VARSIZE(cs->cmddata_buf, 
-                        VARHDRSZ + (cp - VARDATA(cs->cmddata_buf)));
+		SET_VARSIZE(cs->cmddata_buf,
+					VARHDRSZ + (cp - VARDATA(cs->cmddata_buf)));
 	}
 	else if (TRIGGER_FIRED_BY_UPDATE(tg->tg_event))
 	{
@@ -650,15 +515,15 @@ _Slony_I_logTrigger(PG_FUNCTION_ARGS)
 		int			i;
 		int			need_comma = false;
 		int			need_and = false;
-		char		*OldDateStyle;
+		char	   *OldDateStyle;
 
 		char	   *cp = VARDATA(cs->cmddata_buf);
 
 		/*
 		 * UPDATE
 		 *
-		 * cmdtype = 'U' cmddata = "col_ident"='value' [, ...] where "pk_ident" =
-		 * 'value' [ and ...]
+		 * cmdtype = 'U' cmddata = "col_ident"='value' [, ...] where
+		 * "pk_ident" = 'value' [ and ...]
 		 */
 		cmdtype = cs->cmdtype_U;
 		for (i = 0; i < tg->tg_relation->rd_att->natts; i++)
@@ -741,27 +606,29 @@ _Slony_I_logTrigger(PG_FUNCTION_ARGS)
 			else
 				need_comma = true;
 
-			col_ident = (char *)slon_quote_identifier(SPI_fname(tupdesc, i + 1));
+			col_ident = (char *) slon_quote_identifier(SPI_fname(tupdesc, i + 1));
 			if (new_isnull)
 				col_value = "NULL";
 			else
 			{
-				OldDateStyle=GetConfigOptionByName("DateStyle", NULL);
-				set_config_option("DateStyle", "ISO", PGC_USERSET, PGC_S_SESSION, true, true);
+				OldDateStyle = GetConfigOptionByName("DateStyle", NULL);
+				if (!strstr(OldDateStyle, "ISO"))
+					set_config_option("DateStyle", "ISO", PGC_USERSET, PGC_S_SESSION, true, true);
 				col_value = slon_quote_literal(SPI_getvalue(new_row, tupdesc, i + 1));
-				set_config_option("DateStyle", OldDateStyle, PGC_USERSET, PGC_S_SESSION, true, true);
+				if (!strstr(OldDateStyle, "ISO"))
+					set_config_option("DateStyle", OldDateStyle, PGC_USERSET, PGC_S_SESSION, true, true);
 			}
-			cmddata_need = (cp - (char *)(cs->cmddata_buf)) + 16 +
+			cmddata_need = (cp - (char *) (cs->cmddata_buf)) + 16 +
 				(len_ident = strlen(col_ident)) +
 				(len_value = strlen(col_value));
 			if (cs->cmddata_size < cmddata_need)
 			{
-				int			have = (cp - (char *)(cs->cmddata_buf));
+				int			have = (cp - (char *) (cs->cmddata_buf));
 
 				while (cs->cmddata_size < cmddata_need)
 					cs->cmddata_size *= 2;
 				cs->cmddata_buf = realloc(cs->cmddata_buf, cs->cmddata_size);
-				cp = (char *)(cs->cmddata_buf) + have;
+				cp = (char *) (cs->cmddata_buf) + have;
 			}
 
 			memcpy(cp, col_ident, len_ident);
@@ -786,23 +653,26 @@ _Slony_I_logTrigger(PG_FUNCTION_ARGS)
 					continue;
 
 				attkind_idx++;
+				if (!attkind[attkind_idx])
+					elog(ERROR, "Slony-I: no key columns found in logTrigger() attkind parameter");
+
 				if (attkind[attkind_idx] == 'k')
 					break;
 			}
-			col_ident = (char *)slon_quote_identifier(SPI_fname(tupdesc, i + 1));
+			col_ident = (char *) slon_quote_identifier(SPI_fname(tupdesc, i + 1));
 			col_value = slon_quote_literal(SPI_getvalue(old_row, tupdesc, i + 1));
 
-			cmddata_need = (cp - (char *)(cs->cmddata_buf)) + 16 +
+			cmddata_need = (cp - (char *) (cs->cmddata_buf)) + 16 +
 				(len_ident = strlen(col_ident)) +
 				(len_value = strlen(col_value));
 			if (cs->cmddata_size < cmddata_need)
 			{
-				int			have = (cp - (char *)(cs->cmddata_buf));
+				int			have = (cp - (char *) (cs->cmddata_buf));
 
 				while (cs->cmddata_size < cmddata_need)
 					cs->cmddata_size *= 2;
 				cs->cmddata_buf = realloc(cs->cmddata_buf, cs->cmddata_size);
-				cp = (char *)(cs->cmddata_buf) + have;
+				cp = (char *) (cs->cmddata_buf) + have;
 			}
 
 			memcpy(cp, col_ident, len_ident);
@@ -829,25 +699,27 @@ _Slony_I_logTrigger(PG_FUNCTION_ARGS)
 				continue;
 
 			attkind_idx++;
+			if (!attkind[attkind_idx])
+				break;
 			if (attkind[attkind_idx] != 'k')
 				continue;
-			col_ident = (char *)slon_quote_identifier(SPI_fname(tupdesc, i + 1));
+			col_ident = (char *) slon_quote_identifier(SPI_fname(tupdesc, i + 1));
 			col_value = slon_quote_literal(SPI_getvalue(old_row, tupdesc, i + 1));
 			if (col_value == NULL)
-				elog(ERROR, "Slony-I: old key column %s.%s IS NULL on UPDATE", 
-					NameStr(tg->tg_relation->rd_rel->relname), col_ident);
+				elog(ERROR, "Slony-I: old key column %s.%s IS NULL on UPDATE",
+					 NameStr(tg->tg_relation->rd_rel->relname), col_ident);
 
-			cmddata_need = (cp - (char *)(cs->cmddata_buf)) + 16 +
+			cmddata_need = (cp - (char *) (cs->cmddata_buf)) + 16 +
 				(len_ident = strlen(col_ident)) +
 				(len_value = strlen(col_value));
 			if (cs->cmddata_size < cmddata_need)
 			{
-				int			have = (cp - (char *)(cs->cmddata_buf));
+				int			have = (cp - (char *) (cs->cmddata_buf));
 
 				while (cs->cmddata_size < cmddata_need)
 					cs->cmddata_size *= 2;
 				cs->cmddata_buf = realloc(cs->cmddata_buf, cs->cmddata_size);
-				cp = (char *)(cs->cmddata_buf) + have;
+				cp = (char *) (cs->cmddata_buf) + have;
 			}
 
 			if (need_and)
@@ -869,7 +741,7 @@ _Slony_I_logTrigger(PG_FUNCTION_ARGS)
 		}
 		*cp = '\0';
 		SET_VARSIZE(cs->cmddata_buf,
-			VARHDRSZ + (cp - VARDATA(cs->cmddata_buf)));
+					VARHDRSZ + (cp - VARDATA(cs->cmddata_buf)));
 	}
 	else if (TRIGGER_FIRED_BY_DELETE(tg->tg_event))
 	{
@@ -896,25 +768,27 @@ _Slony_I_logTrigger(PG_FUNCTION_ARGS)
 				continue;
 
 			attkind_idx++;
+			if (!attkind[attkind_idx])
+				break;
 			if (attkind[attkind_idx] != 'k')
 				continue;
-			col_ident = (char *)slon_quote_identifier(SPI_fname(tupdesc, i + 1));
+			col_ident = (char *) slon_quote_identifier(SPI_fname(tupdesc, i + 1));
 			col_value = slon_quote_literal(SPI_getvalue(old_row, tupdesc, i + 1));
 			if (col_value == NULL)
-				elog(ERROR, "Slony-I: old key column %s.%s IS NULL on DELETE", 
-					NameStr(tg->tg_relation->rd_rel->relname), col_ident);
+				elog(ERROR, "Slony-I: old key column %s.%s IS NULL on DELETE",
+					 NameStr(tg->tg_relation->rd_rel->relname), col_ident);
 
-			cmddata_need = (cp - (char *)(cs->cmddata_buf)) + 16 +
+			cmddata_need = (cp - (char *) (cs->cmddata_buf)) + 16 +
 				(len_ident = strlen(col_ident)) +
 				(len_value = strlen(col_value));
 			if (cs->cmddata_size < cmddata_need)
 			{
-				int			have = (cp - (char *)(cs->cmddata_buf));
+				int			have = (cp - (char *) (cs->cmddata_buf));
 
 				while (cs->cmddata_size < cmddata_need)
 					cs->cmddata_size *= 2;
 				cs->cmddata_buf = realloc(cs->cmddata_buf, cs->cmddata_size);
-				cp = (char *)(cs->cmddata_buf) + have;
+				cp = (char *) (cs->cmddata_buf) + have;
 			}
 
 			if (need_and)
@@ -936,7 +810,7 @@ _Slony_I_logTrigger(PG_FUNCTION_ARGS)
 		}
 		*cp = '\0';
 		SET_VARSIZE(cs->cmddata_buf,
-			VARHDRSZ + (cp - VARDATA(cs->cmddata_buf)));
+					VARHDRSZ + (cp - VARDATA(cs->cmddata_buf)));
 	}
 	else
 		elog(ERROR, "Slony-I: logTrigger() fired for unhandled event");
@@ -944,10 +818,9 @@ _Slony_I_logTrigger(PG_FUNCTION_ARGS)
 	/*
 	 * Construct the parameter array and insert the log row.
 	 */
-	argv[0] = TransactionIdGetDatum(cs->currentXid);
-	argv[1] = Int32GetDatum(tab_id);
-	argv[2] = PointerGetDatum(cmdtype);
-	argv[3] = PointerGetDatum(cs->cmddata_buf);
+	argv[0] = Int32GetDatum(tab_id);
+	argv[1] = PointerGetDatum(cmdtype);
+	argv[2] = PointerGetDatum(cs->cmddata_buf);
 	SPI_execp(cs->plan_active_log, argv, NULL, 0);
 
 	SPI_finish();
@@ -958,10 +831,7 @@ _Slony_I_logTrigger(PG_FUNCTION_ARGS)
 Datum
 _Slony_I_denyAccess(PG_FUNCTION_ARGS)
 {
-	Slony_I_ClusterStatus *cs;
 	TriggerData *tg;
-	int			rc;
-	Name		cluster_name;
 
 	/*
 	 * Get the trigger call context
@@ -983,38 +853,19 @@ _Slony_I_denyAccess(PG_FUNCTION_ARGS)
 	/*
 	 * Connect to the SPI manager
 	 */
-	if ((rc = SPI_connect()) < 0)
+	if (SPI_connect() < 0)
 		elog(ERROR, "Slony-I: SPI_connect() failed in denyAccess()");
 
 	/*
-	 * Get all the trigger arguments
+	 * If the replication role is: ORIGIN - default role --> FAIL REPLICA -
+	 * this trigger will not fire in --> N/A LOCAL - role when running "local
+	 * updates" --> PERMIT UPDATE
 	 */
-	cluster_name = DatumGetName(DirectFunctionCall1(namein,
-								CStringGetDatum(tg->tg_trigger->tgargs[0])));
-
-	/*
-	 * Get or create the cluster status information and make sure it has the
-	 * SPI plans that we need here.
-	 */
-	cs = getClusterStatus(cluster_name, PLAN_INSERT_LOG);
-
-	/*
-	 * Check/set the session role
-	 */
-	switch (cs->session_role)
-	{
-		case SLON_ROLE_UNSET:	/* Unknown or Normal is not allowed here */
-		case SLON_ROLE_NORMAL:
-			cs->session_role = SLON_ROLE_NORMAL;
-			elog(ERROR,
-				 "Slony-I: Table %s is replicated and cannot be "
-				 "modified on a subscriber node",
-				 NameStr(tg->tg_relation->rd_rel->relname));
-			break;
-
-		case SLON_ROLE_SLON:	/* Replication session, nothing to do here */
-			break;
-	}
+	if (SessionReplicationRole == SESSION_REPLICATION_ROLE_ORIGIN)
+		elog(ERROR,
+			 "Slony-I: Table %s is replicated and cannot be "
+			 "modified on a subscriber node - role=%d",
+		  NameStr(tg->tg_relation->rd_rel->relname), SessionReplicationRole);
 
 	SPI_finish();
 	if (TRIGGER_FIRED_BY_UPDATE(tg->tg_event))
@@ -1051,7 +902,7 @@ _Slony_I_lockedSet(PG_FUNCTION_ARGS)
 		 "because of MOVE_SET operation in progress",
 		 NameStr(tg->tg_relation->rd_rel->relname));
 
-	return (Datum)0;
+	return (Datum) 0;
 }
 
 
@@ -1091,6 +942,71 @@ _Slony_I_killBackend(PG_FUNCTION_ARGS)
 }
 
 
+typedef struct
+{
+	int32		seqid;
+	int64		seqval;
+} SeqTrack_elem;
+
+static int
+seqtrack_cmp(void *seq1, void *seq2)
+{
+	return (((SeqTrack_elem *) seq1)->seqid - ((SeqTrack_elem *) seq2)->seqid);
+}
+
+static void
+seqtrack_free(void *seq)
+{
+	free(seq);
+}
+
+Datum
+_Slony_I_seqtrack(PG_FUNCTION_ARGS)
+{
+	static AVLtree seqmem = AVL_INITIALIZER(seqtrack_cmp, seqtrack_free);
+	AVLnode    *node;
+	SeqTrack_elem *elem;
+	int32		seqid;
+	int64		seqval;
+
+	seqid = PG_GETARG_INT32(0);
+	seqval = PG_GETARG_INT64(1);
+
+	/*
+	 * Try to insert the sequence id into the AVL tree.
+	 */
+	if ((node = avl_insert(&seqmem, &seqid)) == NULL)
+		elog(ERROR, "Slony-I: unexpected NULL return from avl_insert()");
+
+	if (AVL_DATA(node) == NULL)
+	{
+		/*
+		 * This is a new (not seen before) sequence. Create the element,
+		 * remember the current lastval and return it to the caller.
+		 */
+		elem = (SeqTrack_elem *) malloc(sizeof(SeqTrack_elem));
+		elem->seqid = seqid;
+		elem->seqval = seqval;
+		AVL_SETDATA(node, elem);
+
+		PG_RETURN_INT64(seqval);
+	}
+
+	/*
+	 * This is a sequence seen before. If the value has changed remember and
+	 * return it. If it did not, return NULL.
+	 */
+	elem = AVL_DATA(node);
+
+	if (elem->seqval == seqval)
+		PG_RETURN_NULL();
+	else
+		elem->seqval = seqval;
+
+	PG_RETURN_INT64(seqval);
+}
+
+
 static char *
 slon_quote_literal(char *str)
 {
@@ -1111,7 +1027,7 @@ slon_quote_literal(char *str)
 	*cp2++ = '\'';
 	while (len > 0)
 	{
-		if ((wl = pg_mblen((unsigned char *)cp1)) != 1)
+		if ((wl = pg_mblen((unsigned char *) cp1)) != 1)
 		{
 			len -= wl;
 
@@ -1143,7 +1059,7 @@ slon_quote_literal(char *str)
  *
  * Version: pgsql/src/backend/utils/adt/ruleutils.c,v 1.188 2005/01/13 17:19:10
  */
-const char *
+static const char *
 slon_quote_identifier(const char *ident)
 {
 	/*
@@ -1189,8 +1105,8 @@ slon_quote_identifier(const char *ident)
 		 * parser doesn't provide any easy way to test for whether an
 		 * identifier is safe or not... so be safe not sorry.
 		 *
-		 * Note: ScanKeywordLookup() does case-insensitive comparison, but that's
-		 * fine, since we already know we have all-lower-case.
+		 * Note: ScanKeywordLookup() does case-insensitive comparison, but
+		 * that's fine, since we already know we have all-lower-case.
 		 */
 
 #ifdef SCANKEYWORDLOOKUP_1
@@ -1205,7 +1121,7 @@ slon_quote_identifier(const char *ident)
 	if (safe)
 		return ident;			/* no change needed */
 
-	result = (char *)palloc(strlen(ident) + nquotes + 2 + 1);
+	result = (char *) palloc(strlen(ident) + nquotes + 2 + 1);
 
 	optr = result;
 	*optr++ = '"';
@@ -1242,7 +1158,7 @@ _slon_quote_ident(PG_FUNCTION_ARGS)
 
 	/* We have to convert to a C string to use quote_identifier */
 	len = VARSIZE(t) - VARHDRSZ;
-	str = (char *)palloc(len + 1);
+	str = (char *) palloc(len + 1);
 	memcpy(str, VARDATA(t), len);
 	str[len] = '\0';
 
@@ -1265,9 +1181,9 @@ getClusterStatus(Name cluster_name, int need_plan_mask)
 	int			rc;
 	char		query[1024];
 	bool		isnull;
-	Oid			plan_types[12];
-	Oid			xxid_typid;
-	TypeName   *xxid_typename;
+	Oid			plan_types[9];
+	Oid			txid_snapshot_typid;
+	TypeName   *txid_snapshot_typname;
 
 	/*
 	 * Find an existing cs row for this cluster
@@ -1337,20 +1253,6 @@ getClusterStatus(Name cluster_name, int need_plan_mask)
 		clusterStatusList = cs;
 	}
 
-	/*
-	 * Prepare and save the PLAN_NOTIFY_EVENT
-	 */
-	if ((need_plan_mask & PLAN_NOTIFY_EVENT) != 0 &&
-		(cs->have_plan & PLAN_NOTIFY_EVENT) == 0)
-	{
-		sprintf(query, "NOTIFY \"%s_Event\";", NameStr(cs->clustername));
-		cs->plan_notify_event = SPI_saveplan(SPI_prepare(query, 0, NULL));
-		if (cs->plan_notify_event == NULL)
-			elog(ERROR, "Slony-I: SPI_prepare() failed");
-
-		cs->have_plan |= PLAN_NOTIFY_EVENT;
-	}
-
 	/*
 	 * Prepare and save the PLAN_INSERT_EVENT
 	 */
@@ -1358,23 +1260,14 @@ getClusterStatus(Name cluster_name, int need_plan_mask)
 		(cs->have_plan & PLAN_INSERT_EVENT) == 0)
 	{
 		/*
-		 * Lookup the oid of our special xxid type
+		 * Lookup the oid of the txid_snapshot type
 		 */
-		xxid_typename = makeNode(TypeName);
-		xxid_typename->names =
-			lappend(lappend(NIL, makeString(NameStr(cs->clustername))),
-					makeString("xxid"));
+		txid_snapshot_typname = makeNode(TypeName);
+		txid_snapshot_typname->names =
+			lappend(lappend(NIL, makeString("pg_catalog")),
+					makeString("txid_snapshot"));
 
-#ifdef HAVE_TYPENAMETYPEID_3
-              xxid_typid = typenameTypeId(NULL,xxid_typename,NULL);
-#else
-#ifdef HAVE_TYPENAMETYPEID_2
-		xxid_typid = typenameTypeId(NULL,xxid_typename);
-#else
-		xxid_typid = typenameTypeId(xxid_typename);
-#endif
-#endif
-		plan_types[0] = INT4OID;
+		txid_snapshot_typid = typenameTypeId(NULL, txid_snapshot_typname, NULL);
 
 		/*
 		 * Create the saved plan. We lock the sl_event table in exclusive mode
@@ -1385,18 +1278,18 @@ getClusterStatus(Name cluster_name, int need_plan_mask)
 				"LOCK TABLE %s.sl_event IN EXCLUSIVE MODE; "
 				"INSERT INTO %s.sl_event "
 				"(ev_origin, ev_seqno, "
-				"ev_timestamp, ev_minxid, ev_maxxid, ev_xip, "
+				"ev_timestamp, ev_snapshot, "
 				"ev_type, ev_data1, ev_data2, ev_data3, ev_data4, "
 				"ev_data5, ev_data6, ev_data7, ev_data8) "
 				"VALUES ('%d', nextval('%s.sl_event_seq'), "
-				"now(), $1, $2, $3, "
-				"$4, $5, $6, $7, $8, $9, $10, $11, $12); "
+				"now(), \"pg_catalog\".txid_current_snapshot(), $1, $2, "
+				"$3, $4, $5, $6, $7, $8, $9); "
 				"SELECT currval('%s.sl_event_seq');",
 				cs->clusterident,
 				cs->clusterident, cs->localNodeId, cs->clusterident,
 				cs->clusterident);
-		plan_types[0] = xxid_typid;
-		plan_types[1] = xxid_typid;
+		plan_types[0] = TEXTOID;
+		plan_types[1] = TEXTOID;
 		plan_types[2] = TEXTOID;
 		plan_types[3] = TEXTOID;
 		plan_types[4] = TEXTOID;
@@ -1404,11 +1297,8 @@ getClusterStatus(Name cluster_name, int need_plan_mask)
 		plan_types[6] = TEXTOID;
 		plan_types[7] = TEXTOID;
 		plan_types[8] = TEXTOID;
-		plan_types[9] = TEXTOID;
-		plan_types[10] = TEXTOID;
-		plan_types[11] = TEXTOID;
 
-		cs->plan_insert_event = SPI_saveplan(SPI_prepare(query, 12, plan_types));
+		cs->plan_insert_event = SPI_saveplan(SPI_prepare(query, 9, plan_types));
 		if (cs->plan_insert_event == NULL)
 			elog(ERROR, "Slony-I: SPI_prepare() failed");
 
@@ -1419,18 +1309,15 @@ getClusterStatus(Name cluster_name, int need_plan_mask)
 		sprintf(query,
 				"insert into %s.sl_seqlog "
 				"(seql_seqid, seql_origin, seql_ev_seqno, seql_last_value) "
-		   "select seq_id, '%d', currval('%s.sl_event_seq'), seq_last_value "
+				"select * from ("
+			 "select seq_id, %d, currval('%s.sl_event_seq'), seq_last_value "
 				"from %s.sl_seqlastvalue "
-				"where seq_origin = '%d'; "
-				"insert into %s.sl_seqlog "
-				"(seql_seqid, seql_origin, seql_ev_seqno, seql_last_value) "
-				"select '0', '%d', currval('%s.sl_event_seq'), "
-				" last_value from %s.sl_rowid_seq; ",
+				"where seq_origin = '%d') as FOO "
+				"where NOT %s.seqtrack(seq_id, seq_last_value) IS NULL; ",
 				cs->clusterident,
 				cs->localNodeId, cs->clusterident,
 				cs->clusterident, cs->localNodeId,
-				cs->clusterident, cs->localNodeId,
-				cs->clusterident, cs->clusterident);
+				cs->clusterident);
 
 		cs->plan_record_sequences = SPI_saveplan(SPI_prepare(query, 0, NULL));
 		if (cs->plan_record_sequences == NULL)
@@ -1445,56 +1332,39 @@ getClusterStatus(Name cluster_name, int need_plan_mask)
 	if ((need_plan_mask & PLAN_INSERT_LOG) != 0 &&
 		(cs->have_plan & PLAN_INSERT_LOG) == 0)
 	{
-		/*
-		 * Lookup the oid of our special xxid type
-		 */
-		xxid_typename = makeNode(TypeName);
-		xxid_typename->names =
-			lappend(lappend(NIL, makeString(NameStr(cs->clustername))),
-					makeString("xxid"));
-#ifdef HAVE_TYPENAMETYPEID_3
-                xxid_typid = typenameTypeId(NULL, xxid_typename,NULL);
-#else
-#ifdef HAVE_TYPENAMETYPEID_2
-		xxid_typid = typenameTypeId(NULL, xxid_typename);
-#else
-		xxid_typid = typenameTypeId(xxid_typename);
-#endif
-#endif
-
 		/*
 		 * Create the saved plan's
 		 */
 		sprintf(query, "INSERT INTO %s.sl_log_1 "
-				"(log_origin, log_xid, log_tableid, log_actionseq,"
+				"(log_origin, log_txid, log_tableid, log_actionseq,"
 				" log_cmdtype, log_cmddata) "
-				"VALUES (%d, $1, $2, nextval('%s.sl_action_seq'),"
-				" $3, $4);",
+				"VALUES (%d, \"pg_catalog\".txid_current(), $1, "
+				"nextval('%s.sl_action_seq'), $2, $3); ",
 				cs->clusterident, cs->localNodeId, cs->clusterident);
-		plan_types[0] = xxid_typid;
-		plan_types[1] = INT4OID;
+		plan_types[0] = INT4OID;
+		plan_types[1] = TEXTOID;
 		plan_types[2] = TEXTOID;
-		plan_types[3] = TEXTOID;
 
-		cs->plan_insert_log_1 = SPI_saveplan(SPI_prepare(query, 4, plan_types));
+		cs->plan_insert_log_1 = SPI_saveplan(SPI_prepare(query, 3, plan_types));
 		if (cs->plan_insert_log_1 == NULL)
 			elog(ERROR, "Slony-I: SPI_prepare() failed");
 
 		sprintf(query, "INSERT INTO %s.sl_log_2 "
-				"(log_origin, log_xid, log_tableid, log_actionseq,"
+				"(log_origin, log_txid, log_tableid, log_actionseq,"
 				" log_cmdtype, log_cmddata) "
-				"VALUES (%d, $1, $2, nextval('%s.sl_action_seq'),"
-				" $3, $4);",
+				"VALUES (%d, \"pg_catalog\".txid_current(), $1, "
+				"nextval('%s.sl_action_seq'), $2, $3); ",
 				cs->clusterident, cs->localNodeId, cs->clusterident);
-		plan_types[0] = xxid_typid;
-		plan_types[1] = INT4OID;
+		plan_types[0] = INT4OID;
+		plan_types[1] = TEXTOID;
 		plan_types[2] = TEXTOID;
-		plan_types[3] = TEXTOID;
 
-		cs->plan_insert_log_2 = SPI_saveplan(SPI_prepare(query, 4, plan_types));
+		cs->plan_insert_log_2 = SPI_saveplan(SPI_prepare(query, 3, plan_types));
 		if (cs->plan_insert_log_2 == NULL)
 			elog(ERROR, "Slony-I: SPI_prepare() failed");
 
+		/* @-nullderef@ */
+
 		/*
 		 * Also create the 3 rather static text values for the log_cmdtype
 		 * parameter and initialize the cmddata_buf.
@@ -1523,6 +1393,7 @@ getClusterStatus(Name cluster_name, int need_plan_mask)
 	}
 
 	return cs;
+	/* @+nullderef@ */
 }
 
 
