@@ -1,15 +1,13 @@
+/* $Id: confoptions.h,v 1.38 2008-04-23 20:35:43 cbbrowne Exp $ */
 #ifndef _CONFOPTIONS_H_
 #define _CONFOPTIONS_H_
 
-#include "c.h"
-
-
 void		InitializeConfOptions(void);
 
 bool		set_config_option(const char *name, const char *value);
 void	   *get_config_option(const char *name);
 
-extern double real_placeholder;
+void		dump_configuration(void);
 
 extern char *rtcfg_cluster_name;
 extern char *rtcfg_conninfo;
@@ -17,12 +15,12 @@ extern char *rtcfg_conninfo;
 extern char *pid_file;
 extern char *archive_dir;
 
-extern int	vac_frequency;
 extern int	slon_log_level;
 extern int	sync_interval;
 extern int	sync_interval_timeout;
 extern int	sync_max_rowsize;
 extern int	sync_max_largemem;
+extern int	remote_listen_timeout;
 
 extern int	sync_group_maxsize;
 extern int	desired_sync_time;
@@ -30,6 +28,16 @@ extern int	desired_sync_time;
 extern int	quit_sync_provider;
 extern int	quit_sync_finalsync;
 
+/*
+ * ----------
+ * Global variables in cleanup_thread.c
+ * ----------
+ */
+
+extern int	vac_frequency;
+extern char *cleanup_interval;
+extern bool cleanup_deletelogs;
+
 char	   *Syslog_ident;
 char	   *Syslog_facility;
 int			Use_syslog;
@@ -40,7 +48,7 @@ bool		drop_indices;
 char	   *log_timestamp_format;
 char	   *sql_on_connection;
 char	   *lag_interval;
-char       *command_on_logarchive;
+char	   *command_on_logarchive;
 
 enum config_type
 {
@@ -54,8 +62,8 @@ struct config_generic
 {
 	/* constant fields, must be set correctly in initial value: */
 	const char *name;
-				const char *short_desc;
-				const char *long_desc;
+	const char *short_desc;
+	const char *long_desc;
 	enum config_type vartype;	/* type of variable (set only at startup) */
 };
 
@@ -97,7 +105,7 @@ struct config_string
 	/* these fields must be set correctly in initial value: */
 	/* (all are constants) */
 	char	  **variable;
-				const char *default_val;
+	const char *default_val;
 };
 
 
@@ -106,7 +114,6 @@ static struct config_int ConfigureNamesInt[];
 static struct config_bool ConfigureNamesBool[];
 static struct config_real ConfigureNamesReal[];
 static struct config_string ConfigureNamesString[];
-
 #endif
 /*
  * Local Variables:
