@@ -6,7 +6,7 @@
  *	Copyright (c) 2003-2009, PostgreSQL Global Development Group
  *	Author: Jan Wieck, Afilias USA INC.
  *
- *	
+ *	$Id: dbutils.c,v 1.30.2.4 2009-12-09 20:58:15 cbbrowne Exp $
  * ----------------------------------------------------------------------
  */
 
@@ -23,13 +23,10 @@
 #include <sys/time.h>
 #include <sys/types.h>
 
-#include "libpq-fe.h"
-#include "c.h"
-
 #include "slon.h"
 
 
-static int	slon_appendquery_int(SlonDString * dsp, char *fmt, va_list ap);
+static int	slon_appendquery_int(SlonDString *dsp, char *fmt, va_list ap);
 static int	db_get_version(PGconn *conn);
 
 #if (PG_VERSION_MAJOR < 8)
@@ -47,7 +44,7 @@ static pthread_mutex_t slon_connect_lock = PTHREAD_MUTEX_INITIALIZER;
 
 
 /* ----------
- * slon_connectdb 
+ * slon_connectdb
  * ----------
  */
 SlonConn *
@@ -109,7 +106,7 @@ slon_connectdb(char *conninfo, char *symname)
 		slon_log(SLON_ERROR, "Unable to set the datestyle to ISO\n");
 	}
 	PQclear(res);
-	
+
 	/*
 	 * Embed it into a SlonConn structure used to exchange it with the
 	 * scheduler. On return this new connection object is locked.
@@ -117,49 +114,65 @@ slon_connectdb(char *conninfo, char *symname)
 	conn = slon_make_dummyconn(symname);
 	conn->dbconn = dbconn;
 	conn->pg_version = db_get_version(dbconn);
-        if (conn->pg_version < 70400)
-        {
-                slon_log(SLON_ERROR,
-                        "slon_connectdb: PQconnectdb(\"%s\") PostgreSQL version not supported\n",
-                        conninfo);
-                PQfinish(dbconn);
-                return NULL;
-        }
-	
-        slon_log(SLON_DEBUG4,
-                "version for \"%s\" is %d\n", conninfo, conn->pg_version);
-
-	if (conn->pg_version >= 80100)
-        {
-                slon_mkquery(&query, "set escape_string_warning to 'off'");
-                res = PQexec(dbconn, dstring_data(&query));
-                if (!(PQresultStatus(res) == PGRES_COMMAND_OK))
-                {
-                        slon_log(SLON_ERROR, "Unable to set escape_string_warning to off\n");
-                }
-                PQclear(res);
-        }
-	if (conn->pg_version >= 80200)
+	if (conn->pg_version < 80300)
 	{
+		slon_log(SLON_ERROR,
+				 "slon_connectdb: PQconnectdb(\"%s\") PostgreSQL version not supported\n",
+				 conninfo);
+		PQfinish(dbconn);
+		return NULL;
+	}
+
+	slon_log(SLON_CONFIG,
+			 "version for \"%s\" is %d\n", conninfo, conn->pg_version);
+
+	if (conn->pg_version >= 80300)
+	{
+		slon_mkquery(&query, "set escape_string_warning to 'off'");
+		res = PQexec(dbconn, dstring_data(&query));
+		if (!(PQresultStatus(res) == PGRES_COMMAND_OK))
+		{
+			slon_log(SLON_ERROR, "Unable to set escape_string_warning to off\n");
+		}
+		PQclear(res);
+
 		slon_mkquery(&query, "set standard_conforming_strings to 'off'");
 		res = PQexec(dbconn, dstring_data(&query));
 		if (!(PQresultStatus(res) == PGRES_COMMAND_OK))
 		{
 			slon_log(SLON_ERROR, "Unable to set the standard_conforming_strings to off\n");
-        	}
+		}
 		PQclear(res);
 	}
+
+	if (slon_log_level >= SLON_DEBUG1)
+	{
+		slon_mkquery(&query, "select pg_backend_pid()");
+		res = PQexec(dbconn, dstring_data(&query));
+		if (!res || PQresultStatus(res) != PGRES_TUPLES_OK)
+		{
+			slon_log(SLON_ERROR, "%s: Unable to get backend pid - %s\n",
+				symname, PQresultErrorMessage(res));
+		}
+		else
+		{
+			slon_log(SLON_DEBUG1, "%s \"%s\": backend pid = %s\n",
+				symname, conninfo, PQgetvalue(res, 0, 0));
+		}
+		PQclear(res);
+	}
+
 	dstring_free(&query);
 	return conn;
 }
 
 
 /* ----------
- * slon_disconnectdb 
+ * slon_disconnectdb
  * ----------
  */
 void
-slon_disconnectdb(SlonConn * conn)
+slon_disconnectdb(SlonConn *conn)
 {
 	/*
 	 * Disconnect the native database connection
@@ -177,7 +190,7 @@ slon_disconnectdb(SlonConn * conn)
 
 
 /* ----------
- * slon_make_dummyconn 
+ * slon_make_dummyconn
  * ----------
  */
 SlonConn *
@@ -209,11 +222,11 @@ slon_make_dummyconn(char *symname)
 
 
 /* ----------
- * slon_free_dummyconn 
+ * slon_free_dummyconn
  * ----------
  */
 void
-slon_free_dummyconn(SlonConn * conn)
+slon_free_dummyconn(SlonConn *conn)
 {
 	/*
 	 * Destroy and unlock the condition and mutex variables
@@ -236,7 +249,7 @@ slon_free_dummyconn(SlonConn * conn)
 /* ----------
  * db_getLocalNodeId
  *
- * Query a connection for the value of sequence sl_local_node_id 
+ * Query a connection for the value of sequence sl_local_node_id
  * ----------
  */
 int
@@ -382,14 +395,14 @@ db_checkSchemaVersion(PGconn *conn)
  * slon_mkquery
  *
  * A simple query formatting and quoting function using dynamic string buffer
- * allocation. Similar to sprintf() it uses formatting symbols: 
- *     %s	String argument
- *     %q	Quoted literal (\ and ' will be escaped)
- *     %d	Integer argument 
+ * allocation. Similar to sprintf() it uses formatting symbols:
+ *	   %s	String argument
+ *	   %q	Quoted literal (\ and ' will be escaped)
+ *	   %d	Integer argument
  * ----------
  */
 int
-slon_mkquery(SlonDString * dsp, char *fmt,...)
+slon_mkquery(SlonDString *dsp, char *fmt,...)
 {
 	va_list		ap;
 
@@ -412,7 +425,7 @@ slon_mkquery(SlonDString * dsp, char *fmt,...)
  * ----------
  */
 int
-slon_appendquery(SlonDString * dsp, char *fmt,...)
+slon_appendquery(SlonDString *dsp, char *fmt,...)
 {
 	va_list		ap;
 
@@ -429,11 +442,11 @@ slon_appendquery(SlonDString * dsp, char *fmt,...)
 /* ----------
  * slon_appendquery_int
  *
- * Implementation of slon_mkquery() and slon_appendquery(). 
+ * Implementation of slon_mkquery() and slon_appendquery().
  * ----------
  */
 static int
-slon_appendquery_int(SlonDString * dsp, char *fmt, va_list ap)
+slon_appendquery_int(SlonDString *dsp, char *fmt, va_list ap)
 {
 	char	   *s;
 	char		buf[64];
@@ -511,22 +524,23 @@ slon_appendquery_int(SlonDString * dsp, char *fmt, va_list ap)
 	return 0;
 }
 
-static int db_get_version(PGconn *conn)
+static int
+db_get_version(PGconn *conn)
 {
-	PGresult    *res;
+	PGresult   *res;
 	SlonDString query;
-	char	    versionstr[7];
-	int	    version=0;
-	int	    major=0;
-	int	    minor=0;
-	int	    patch=0;
+	char		versionstr[7];
+	int			version = 0;
+	int			major = 0;
+	int			minor = 0;
+	int			patch = 0;
 
 	dstring_init(&query);
 	slon_mkquery(&query, "SELECT version();");
 	res = PQexec(conn, dstring_data(&query));
 
-	if ( !res || PQresultStatus(res) != PGRES_TUPLES_OK )
-        {
+	if (!res || PQresultStatus(res) != PGRES_TUPLES_OK)
+	{
 		PQclear(res);
 		return -1;
 	}
@@ -537,11 +551,11 @@ static int db_get_version(PGconn *conn)
 	}
 	PQclear(res);
 	snprintf(versionstr, 7, "%.2d%.2d%.2d", major, minor, patch);
-	version=atoi(versionstr);
+	version = atoi(versionstr);
 	dstring_free(&query);
 	return version;
 }
-	
+
 /*
  * Local Variables:
  *	tab-width: 4
