@@ -6,7 +6,7 @@
  *	Copyright (c) 2003-2009, PostgreSQL Global Development Group
  *	Author: Jan Wieck, Afilias USA INC.
  *
- *	
+ *	$Id: runtime_config.c,v 1.28.2.1 2009-08-17 17:09:58 devrim Exp $
  *-------------------------------------------------------------------------
  */
 
@@ -23,8 +23,6 @@
 #include <sys/time.h>
 #include <sys/types.h>
 
-#include "libpq-fe.h"
-#include "c.h"
 #include "slon.h"
 
 
@@ -275,7 +273,7 @@ rtcfg_disableNode(int no_id)
 		rtcfg_unlock();
 
 		slon_log(SLON_FATAL,
-				 "disableNode: unknown node ID %d\n", no_id);
+				 "enableNode: unknown node ID %d\n", no_id);
 		slon_retry();
 		return;
 	}
