@@ -6,7 +6,7 @@
  *	Copyright (c) 2003-2009, PostgreSQL Global Development Group
  *	Author: Jan Wieck, Afilias USA INC.
  *
- *	
+ *	$Id: slon.c,v 1.79.2.1 2009-08-17 17:09:58 devrim Exp $
  *-------------------------------------------------------------------------
  */
 
@@ -47,7 +47,7 @@
 #define		SLON_WATCHDOG_RESTART		1
 #define		SLON_WATCHDOG_RETRY			2
 #define		SLON_WATCHDOG_SHUTDOWN		3
-int			watchdog_status = SLON_WATCHDOG_NORMAL;
+static int			watchdog_status = SLON_WATCHDOG_NORMAL;
 #endif
 int			sched_wakeuppipe[2];
 
@@ -58,6 +58,7 @@ pthread_cond_t slon_wait_listen_cond;
  * Local data 
  * ----------
  */
+static void slon_exit(int code);
 static pthread_t local_event_thread;
 static pthread_t local_cleanup_thread;
 static pthread_t local_sync_thread;
@@ -74,13 +75,13 @@ static void SlonMain(void);
 #ifndef WIN32
 static void SlonWatchdog(void);
 static void sighandler(int signo);
-static void slon_terminate_worker(void);
+void slon_terminate_worker(void);
 #endif
 
 int			slon_log_level;
 char	   *pid_file;
 char	   *archive_dir = NULL;
-int			child_status;
+static int			child_status;
 
 
 /* ----------
@@ -135,6 +136,7 @@ main(int argc, char *const argv[])
 	extern int	optind;
 	extern char *optarg;
 
+
 #ifdef WIN32
 	WSADATA		wsaData;
 	int			err;
@@ -389,6 +391,11 @@ SlonMain(void)
 		slon_abort();
 	}
 
+
+	/* 
+	 * Dump out current configuration - all elements of the various arrays...
+	 */
+	dump_configuration();
 	/*
 	 * Connect to the local database to read the initial configuration
 	 */
@@ -456,7 +463,7 @@ SlonMain(void)
 	}
 #endif
 
-	slon_log(SLON_DEBUG2, "main: main process started\n");
+	slon_log(SLON_INFO, "main: main process started\n");
 
 	/*
 	 * Start the event scheduling system
@@ -650,7 +657,7 @@ SlonMain(void)
 		strcpy(rtcfg_lastevent, PQgetvalue(res, 0, 0));
 	PQclear(res);
 	dstring_free(&query);
-	slon_log(SLON_DEBUG2,
+	slon_log(SLON_CONFIG,
 			 "main: last local event sequence = %s\n",
 			 rtcfg_lastevent);
 
@@ -729,20 +736,20 @@ SlonMain(void)
 	/*
 	 * Wait until the scheduler has shut down all remote connections
 	 */
-	slon_log(SLON_DEBUG1, "main: running scheduler mainloop\n");
+	slon_log(SLON_INFO, "main: running scheduler mainloop\n");
 	if (sched_wait_mainloop() < 0)
 	{
 		slon_log(SLON_FATAL, "main: scheduler returned with error\n");
 		slon_retry();
 	}
-	slon_log(SLON_DEBUG1, "main: scheduler mainloop returned\n");
+	slon_log(SLON_INFO, "main: scheduler mainloop returned\n");
 
 	/*
 	 * Wait for all remote threads to finish
 	 */
 	main_thread = pthread_self();
 
-	slon_log(SLON_DEBUG2, "main: wait for remote threads\n");
+	slon_log(SLON_CONFIG, "main: wait for remote threads\n");
 	rtcfg_joinAllRemoteThreads();
 
 	/*
@@ -766,7 +773,7 @@ SlonMain(void)
 				 strerror(errno));
 #endif
 
-	slon_log(SLON_DEBUG1, "main: done\n");
+	slon_log(SLON_CONFIG, "main: done\n");
 
 	exit(0);
 }
@@ -784,14 +791,14 @@ SlonWatchdog(void)
 #if !defined(CYGWIN) && !defined(WIN32)
 	struct sigaction act;
 #endif
-	slon_log(SLON_DEBUG2, "slon: watchdog process started\n");
+	slon_log(SLON_INFO, "slon: watchdog process started\n");
 
 	/*
 	 * Install signal handlers
 	 */
 #ifndef CYGWIN
 	act.sa_handler = &sighandler;
-	sigemptyset(&act.sa_mask);
+	(void) sigemptyset(&act.sa_mask);
 	act.sa_flags = SA_NODEFER;
 
 	if (sigaction(SIGHUP, &act, NULL) < 0)
@@ -834,7 +841,7 @@ SlonWatchdog(void)
 		slon_exit(-1);
 	}
 
-	slon_log(SLON_DEBUG2, "slon: watchdog ready - pid = %d\n", slon_watchdog_pid);
+	slon_log(SLON_CONFIG, "slon: watchdog ready - pid = %d\n", slon_watchdog_pid);
 
 	slon_worker_pid = fork();
 	if (slon_worker_pid == 0)
@@ -843,23 +850,23 @@ SlonWatchdog(void)
 		exit(-1);
 	}
 
-	slon_log(SLON_DEBUG2, "slon: worker process created - pid = %d\n",
+	slon_log(SLON_CONFIG, "slon: worker process created - pid = %d\n",
 			 slon_worker_pid);
 	while ((pid = wait(&child_status)) != slon_worker_pid)
 	{
 		if (pid < 0 && errno == EINTR)
 			continue;
 
-		slon_log(SLON_DEBUG2, "slon: child terminated status: %d; pid: %d, current worker pid: %d\n", child_status, pid, slon_worker_pid);
+		slon_log(SLON_CONFIG, "slon: child terminated status: %d; pid: %d, current worker pid: %d\n", child_status, pid, slon_worker_pid);
 	}
-	slon_log(SLON_DEBUG2, "slon: child terminated status: %d; pid: %d, current worker pid: %d\n", child_status, pid, slon_worker_pid);
+	slon_log(SLON_CONFIG, "slon: child terminated status: %d; pid: %d, current worker pid: %d\n", child_status, pid, slon_worker_pid);
 
-	alarm(0);
+	(void) alarm(0);
 
 	switch (watchdog_status)
 	{
 		case SLON_WATCHDOG_RESTART:
-			execvp(main_argv[0], main_argv);
+			(void) execvp(main_argv[0], main_argv);
 			slon_log(SLON_FATAL, "slon: cannot restart via execvp() - %s\n",
 					 strerror(errno));
 			slon_exit(-1);
@@ -870,16 +877,16 @@ SlonWatchdog(void)
 			watchdog_status = SLON_WATCHDOG_RETRY;
 			if (child_status != 0)
 			{
-				slon_log(SLON_DEBUG1, "slon: restart of worker in 10 seconds\n");
-				sleep(10);
+				slon_log(SLON_CONFIG, "slon: restart of worker in 10 seconds\n");
+				(void) sleep(10);
 			}
 			else
 			{
-				slon_log(SLON_DEBUG1, "slon: restart of worker\n");
+				slon_log(SLON_CONFIG, "slon: restart of worker\n");
 			}
 			if (watchdog_status == SLON_WATCHDOG_RETRY)
 			{
-				execvp(main_argv[0], main_argv);
+				(void) execvp(main_argv[0], main_argv);
 				slon_log(SLON_FATAL, "slon: cannot restart via execvp() - %s\n",
 						 strerror(errno));
 				slon_exit(-1);
@@ -890,7 +897,7 @@ SlonWatchdog(void)
 			break;
 	}
 
-	slon_log(SLON_DEBUG1, "slon: done\n");
+	slon_log(SLON_INFO, "slon: done\n");
 
 	/*
 	 * That's it.
@@ -909,7 +916,7 @@ sighandler(int signo)
 	switch (signo)
 	{
 		case SIGALRM:
-			slon_log(SLON_DEBUG1, "slon: child termination timeout - kill child\n");
+			slon_log(SLON_INFO, "slon: child termination timeout - kill child\n");
 			kill(slon_worker_pid, SIGKILL);
 			break;
 
@@ -917,31 +924,32 @@ sighandler(int signo)
 			break;
 
 		case SIGHUP:
-			slon_log(SLON_DEBUG1, "slon: restart requested\n");
+			slon_log(SLON_INFO, "slon: restart requested\n");
 			watchdog_status = SLON_WATCHDOG_RESTART;
 			slon_terminate_worker();
 			break;
 
 		case SIGUSR1:
-			slon_log(SLON_DEBUG1, "slon: retry requested\n");
+			slon_log(SLON_INFO, "slon: retry requested\n");
 			watchdog_status = SLON_WATCHDOG_RETRY;
 			slon_terminate_worker();
 			break;
 
 		case SIGINT:
 		case SIGTERM:
-			slon_log(SLON_DEBUG1, "slon: shutdown requested\n");
+			slon_log(SLON_INFO, "slon: shutdown requested\n");
 			watchdog_status = SLON_WATCHDOG_SHUTDOWN;
 			slon_terminate_worker();
 			break;
 
 		case SIGQUIT:
-			slon_log(SLON_DEBUG1, "slon: shutdown now requested\n");
+			slon_log(SLON_INFO, "slon: shutdown now requested\n");
 			kill(slon_worker_pid, SIGKILL);
 			slon_exit(-1);
 			break;
 	}
 }
+#endif
 
 /* ---------- 
  * slon_terminate_worker 
@@ -950,25 +958,26 @@ sighandler(int signo)
 void
 slon_terminate_worker()
 {
-	slon_log(SLON_DEBUG2, "slon: notify worker process to shutdown\n");
+#ifndef WIN32 /* does not support in windows. */
+	slon_log(SLON_INFO, "slon: notify worker process to shutdown\n");
 
 	if (pipewrite(sched_wakeuppipe[1], "p", 1) != 1)
 	{
 		slon_log(SLON_FATAL, "main: write to worker pipe failed -(%d) %s\n", errno, strerror(errno));
-		kill(slon_worker_pid, SIGKILL);
+		(void) kill(slon_worker_pid, SIGKILL);
 		slon_exit(-1);
 	}
-        close(sched_wakeuppipe[0]);
-	close(sched_wakeuppipe[1]);
-	alarm(20);
-}
+        (void) close(sched_wakeuppipe[0]);
+	(void) close(sched_wakeuppipe[1]);
+	(void) alarm(20);
 #endif
+}
 
 /* ---------- 
  * slon_exit 
  * ----------
  */
-void
+static void
 slon_exit(int code)
 {
 #ifdef WIN32
@@ -978,11 +987,11 @@ slon_exit(int code)
 
 	if (pid_file)
 	{
-		slon_log(SLON_DEBUG2, "slon: remove pid file\n");
-		unlink(pid_file);
+		slon_log(SLON_INFO, "slon: remove pid file\n");
+		(void) unlink(pid_file);
 	}
 
-	slon_log(SLON_DEBUG2, "slon: exit(%d)\n", code);
+	slon_log(SLON_INFO, "slon: exit(%d)\n", code);
 
 	exit(code);
 }
