@@ -6,7 +6,7 @@
  *	Copyright (c) 2003-2009, PostgreSQL Global Development Group
  *	Author: Jan Wieck, Afilias USA INC.
  *
- *	
+ *	$Id: slon.h,v 1.68.2.1 2009-08-17 17:09:58 devrim Exp $
  *-------------------------------------------------------------------------
  */
 
@@ -14,8 +14,11 @@
 #define SLON_H_INCLUDED
 
 #include "config.h"
+#include "libpq-fe.h"
+#include "postgres_fe.h"
 #include "misc.h"
 #include "conf-file.h"
+#include "confoptions.h"
 
 #define SLON_MEMDEBUG	1
 
@@ -35,7 +38,7 @@
 #define SLON_WORKLINES_PER_HELPER	(SLON_DATA_FETCH_SIZE * 4)
 #else
 #define SLON_COMMANDS_PER_LINE		10
-#define SLON_DATA_FETCH_SIZE		10
+#define SLON_DATA_FETCH_SIZE		50
 #define SLON_WORKLINES_PER_HELPER	(SLON_DATA_FETCH_SIZE * 5)
 #endif
 
@@ -309,11 +312,14 @@ do { \
  * Scheduler runmodes
  * ----------
  */
-#define SCHED_STATUS_OK			0
-#define SCHED_STATUS_SHUTDOWN	1
-#define SCHED_STATUS_DONE		2
-#define SCHED_STATUS_CANCEL		3
-#define SCHED_STATUS_ERROR		4
+typedef enum
+{
+		SCHED_STATUS_OK,
+		SCHED_STATUS_SHUTDOWN,
+		SCHED_STATUS_DONE,
+		SCHED_STATUS_CANCEL,
+		SCHED_STATUS_ERROR
+} ScheduleStatus;
 
 /* ----------
  * Scheduler wait conditions
@@ -360,7 +366,7 @@ do { \
 	pthread_mutex_lock(&slon_watchdog_lock); \
 	if (slon_watchdog_pid >= 0) { \
 		slon_log(SLON_DEBUG2, "slon_abort() from pid=%d\n", slon_pid); \
-		kill(slon_watchdog_pid, SIGTERM); \
+		(void) kill(slon_watchdog_pid, SIGTERM);			\
 		slon_watchdog_pid = -1; \
 	} \
 	pthread_mutex_unlock(&slon_watchdog_lock); \
@@ -371,7 +377,7 @@ do { \
 	pthread_mutex_lock(&slon_watchdog_lock); \
 	if (slon_watchdog_pid >= 0) { \
 		slon_log(SLON_DEBUG2, "slon_restart() from pid=%d\n", slon_pid); \
-		kill(slon_watchdog_pid, SIGHUP); \
+		(void) kill(slon_watchdog_pid, SIGHUP);			\
 		slon_watchdog_pid = -1; \
 	} \
 	pthread_mutex_unlock(&slon_watchdog_lock); \
@@ -382,7 +388,7 @@ do { \
 	pthread_mutex_lock(&slon_watchdog_lock); \
 	if (slon_watchdog_pid >= 0) { \
 		slon_log(SLON_DEBUG2, "slon_retry() from pid=%d\n", slon_pid); \
-		kill(slon_watchdog_pid, SIGUSR1); \
+		(void) kill(slon_watchdog_pid, SIGUSR1);			\
 		slon_watchdog_pid = -1; \
 	} \
 	pthread_mutex_unlock(&slon_watchdog_lock); \
@@ -408,7 +414,6 @@ do { \
 } while (0)
 #endif
 
-extern void slon_exit(int code);
 extern void Usage(char *const argv[]);
 
 extern int	sched_wakeuppipe[];
@@ -470,6 +475,8 @@ extern void *slon_localEventThread(void *dummy);
  */
 
 extern int	vac_frequency;
+extern char *cleanup_interval;
+extern bool cleanup_deletelogs;
 
 /* ----------
  * Functions in cleanup_thread.c
@@ -529,7 +536,7 @@ extern void *remoteWorkerThread_main(void *cdata);
 extern void remoteWorker_event(int event_provider,
 				   int ev_origin, int64 ev_seqno,
 				   char *ev_timestamp,
-				   char *ev_minxid, char *ev_maxxid, char *ev_xip,
+				   char *ev_snapshot, char *ev_mintxid, char *ev_maxtxid,
 				   char *ev_type,
 				   char *ev_data1, char *ev_data2,
 				   char *ev_data3, char *ev_data4,
