@@ -6,7 +6,7 @@
  *	Copyright (c) 2003-2009, PostgreSQL Global Development Group
  *	Author: Jan Wieck, Afilias USA INC.
  *
- *	
+ *	$Id: dbutil.c,v 1.15.2.2 2010-02-11 23:09:18 cbbrowne Exp $
  *-------------------------------------------------------------------------
  */
 
@@ -138,24 +138,14 @@ db_connect(SlonikStmt * stmt, SlonikAdmInfo * adminfo)
 	PQsetNoticeProcessor(dbconn, db_notice_recv, NULL);
 #endif   /* !HAVE_PQSETNOTICERECEIVER */
 
+	dstring_init(&query);
+	slon_mkquery(&query,"SET datestyle TO 'ISO'; "
+						"SET session_replication_role TO local; ");
+
 	adminfo->dbconn = dbconn;
-
-	dstring_init(&query);
-	slon_mkquery(&query,"SELECT 1 FROM pg_catalog.pg_shadow WHERE usename = user "
-				"AND usesuper");
-	if (PQntuples(db_exec_select(stmt, adminfo, &query)) != 1)
-	{
-		printf("Error: You are not a superuser on node %d\n",adminfo->no_id);
-		dstring_free(&query);
-		return -1;
-	}
-		 
-	dstring_init(&query);
-	slon_mkquery(&query,"SET datestyle to 'ISO'");
-
 	if (db_exec_command(stmt, adminfo, &query) < 0)
 	{
-		printf("Unable to set datestyle\n");
+		printf("Unable to set session configuration parameters\n");
 		dstring_free(&query);
 		return -1;
 	}
@@ -266,6 +256,55 @@ db_exec_evcommand(SlonikStmt * stmt, SlonikAdmInfo * adminfo, SlonDString * quer
 }
 
 
+/* ----------
+ * db_exec_evcommand_p
+ *
+ *	Execute a stored procedure returning an event sequence and remember
+ *	that in the admin info for later wait events. Differs from
+ *	db_exec_evcommand by using PQexecParams().
+ * ----------
+ */
+int
+db_exec_evcommand_p(SlonikStmt * stmt, SlonikAdmInfo * adminfo, 
+		SlonDString * query, int nParams, const Oid *paramTypes,
+		const char *const *paramValues, const int *paramLengths,
+		const int *paramFormats, int resultFormat)
+{
+	PGresult   *res;
+
+	db_notice_stmt = stmt;
+
+	if (db_begin_xact(stmt, adminfo) < 0)
+		return -1;
+
+	res = PQexecParams(adminfo->dbconn, dstring_data(query),
+			nParams, paramTypes, paramValues, paramLengths,
+			paramFormats, resultFormat);
+	if (PQresultStatus(res) != PGRES_TUPLES_OK)
+	{
+		fprintf(stderr, "%s:%d: %s %s - %s",
+				stmt->stmt_filename, stmt->stmt_lno,
+				PQresStatus(PQresultStatus(res)),
+				dstring_data(query), PQresultErrorMessage(res));
+		PQclear(res);
+		return -1;
+	}
+	if (PQntuples(res) != 1)
+	{
+		fprintf(stderr, "%s:%d: %s - did not return 1 row",
+				stmt->stmt_filename, stmt->stmt_lno,
+				dstring_data(query));
+		PQclear(res);
+		return -1;
+	}
+
+	slon_scanint64(PQgetvalue(res, 0, 0), &(adminfo->last_event));
+	PQclear(res);
+
+	return 0;
+}
+
+
 /* ----------
  * db_exec_select
  *
@@ -537,20 +576,6 @@ db_check_requirements(SlonikStmt * stmt, SlonikAdmInfo * adminfo, char *clustern
 		return -1;
 	}
 
-	/*
-	 * Check loading of xxid module
-	 */
-	slon_mkquery(&query, "load '$libdir/xxid'; ");
-	if (db_exec_command(stmt, adminfo, &query) < 0)
-	{
-		printf("%s:%d: Error: the extension for the xxid data type "
-			   "cannot be loaded in database '%s'\n",
-			   stmt->stmt_filename, stmt->stmt_lno,
-			   adminfo->conninfo);
-		dstring_free(&query);
-		return -1;
-	}
-
 	/*
 	 * Check loading of slony1_funcs module
 	 */
