@@ -22,14 +22,16 @@ commit()
 
 generate_initdata()
 {
-  numrows=$(random_number 50 1000)
+  numrows=$(random_number 150 350)
   i=0;
   trippoint=`expr $numrows / 20`
   j=0;
   percent=0
-  status "generating ${numrows} tranactions of random data"
+  status "generating ${numrows} transactions of random data"
   percent=`expr $j \* 5`
   status "$percent %"
+  GENDATA="$mktmp/generate.data"
+  echo "" > ${GENDATA}
   while : ; do
     txtalen=$(random_number 1 100)
     txta=$(random_string ${txtalen})
@@ -37,7 +39,6 @@ generate_initdata()
     txtblen=$(random_number 1 100)
     txtb=$(random_string ${txtblen})
     txtb=`echo ${txtb} | sed -e "s/\\\\\\\/\\\\\\\\\\\\\\/g" -e "s/'/''/g"`
-    GENDATA="$mktmp/generate.data"
     echo "INSERT INTO table1(data) VALUES ('${txta}');" >> $GENDATA
     echo "INSERT INTO table2(table1_id,data) SELECT id, '${txtb}' FROM table1 WHERE data='${txta}';" >> $GENDATA
     echo "INSERT INTO table3(table2_id) SELECT id FROM table2 WHERE data ='${txtb}';" >> $GENDATA
@@ -67,7 +68,6 @@ do_initdata()
   eval user=\$USER${originnode}
   eval port=\$PORT${originnode}
   generate_initdata
-  launch_poll
   status "loading data"
   $pgbindir/psql -h $host -p $port -U $user -d $db < $mktmp/generate.data 1> $LOG 2> $LOG
   if [ $? -ne 0 ]; then
@@ -82,8 +82,27 @@ do_initdata()
 
   status "Generate some more data"
   generate_initdata
-  status "loading extra data"
-  $pgbindir/psql -h $host -U $user -d $db < $mktmp/generate.data 1> $LOG 2> $LOG
+  eval db=\$DB${originnode}
+  status "loading extra data to node $db"
+  $pgbindir/psql -h $host -p $port -U $user -d $db < $mktmp/generate.data 1> $LOG 2> $LOG
+  wait_for_catchup
+
+  status "Execute a script on each node, one by one"
+  for tnode in 1 2 3; do
+      init_preamble
+      sh ${testname}/individual_ddl.sh ${testname} ${tnode} >> ${SCRIPT}
+      status "execute DDL script on node ${tnode}"
+      do_ik
+      status "DDL script completed on node ${tnode}"
+  done
+  wait_for_catchup
+
+  status "Generate still more data"
+  generate_initdata
+  eval db=\$DB${originnode}
+  status "loading extra data to node $db"
+  $pgbindir/psql -h $host -p $port -U $user -d $db < $mktmp/generate.data 1> $LOG 2> $LOG
+  wait_for_catchup
 
   status "done"
 }
