@@ -1,9 +1,9 @@
 #!@@PERL@@
-# 
+# $Id: slon_watchdog2.pl,v 1.11.2.1 2009-08-17 17:09:59 devrim Exp $
 # Author: Christopher Browne
 # Copyright 2004-2009 Afilias Canada
 
-require '@@PGLIBDIR@@/slon-tools.pm';
+require '@@PERLSHAREDIR@@/slon-tools.pm';
 require '@@SYSCONFDIR@@/slon_tools.conf';
 
 $node =$ARGV[0];
