@@ -1,6 +1,6 @@
 #!@@PERL@@
 
-# $Id: slonik_create_set.pl,v 1.3.2.3 2009-08-17 17:39:58 devrim Exp $
+# $Id: slonik_create_set.pl,v 1.6.2.1 2009-08-17 17:09:59 devrim Exp $
 # Author: Christopher Browne
 # Copyright 2004-2009 Afilias Canada
 
@@ -27,7 +27,7 @@ if ($SHOW_USAGE) {
     exit 0;
 }
 
-require '@@PGLIBDIR@@/slon-tools.pm';
+require '@@PERLSHAREDIR@@/slon-tools.pm';
 require $CONFIG_FILE;
 
 my ($set) = @ARGV;
