@@ -1,5 +1,5 @@
 #!@@PERL@@
-# 
+# $Id: slonik_drop_sequence.pl,v 1.1.2.2 2009-08-17 17:09:59 devrim Exp $
 # Author: Mark Stosberg
 # Based on work by: Christopher Browne
 # Parts Copyright 2008 Summerault, LLC
@@ -33,7 +33,7 @@ if ($SHOW_USAGE) {
     exit 0;
 }
 
-require '@@PGLIBDIR@@/slon-tools.pm';
+require '@@PERLSHAREDIR@@/slon-tools.pm';
 require $CONFIG_FILE;
 
 my ($SEQ_ID,$set) = @ARGV;
