@@ -1,5 +1,5 @@
 #!@@PERL@@
-# 
+# $Id: slonik_execute_script.pl,v 1.4.2.1 2009-08-17 17:09:59 devrim Exp $
 # Author: Christopher Browne
 # Copyright 2004-2009 Afilias Canada
 
@@ -50,7 +50,7 @@ if ($SHOW_USAGE) {
   exit 0;
 }
 
-require '@@PGLIBDIR@@/slon-tools.pm';
+require '@@PERLSHAREDIR@@/slon-tools.pm';
 require $CONFIG_FILE;
 
 my ($set, $file) = @ARGV;
