@@ -1,5 +1,5 @@
 #!/usr/bin/perl
-# 
+# $Id: slonik_restart_node.pl,v 1.3.2.1 2009-08-17 17:09:59 devrim Exp $
 # Author: Christopher Browne
 # Copyright 2004-2009 Afilias Canada
 
@@ -27,7 +27,7 @@ if ($SHOW_USAGE) {
   exit 0;
 }
 
-require '@@PGLIBDIR@@/slon-tools.pm';
+require '@@PERLSHAREDIR@@/slon-tools.pm';
 require $CONFIG_FILE;
 
 my @nodes;
