@@ -1,5 +1,5 @@
 #!@@PERL@@
-# $Id: slony_show_configuration.pl,v 1.1.4.2 2009-08-17 17:39:58 devrim Exp $
+# $Id: slony_show_configuration.pl,v 1.3.2.1 2009-08-17 17:09:59 devrim Exp $
 # Author: Christopher Browne
 # Copyright 2004-2009 Afilias Canada
 
@@ -26,7 +26,7 @@ if ($SHOW_USAGE) {
   exit 0;
 }
 
-require '@@PGLIBDIR@@/slon-tools.pm';
+require '@@PERLSHAREDIR@@/slon-tools.pm';
 require $CONFIG_FILE;
 
 print "Slony Configuration\n-------------------------------------\n";
