@@ -1,5 +1,5 @@
 #!/bin/sh
-# $Id: check_slon.sh,v 1.2 2005-03-03 23:44:44 cbbrowne Exp $
+# $Id: check_slon.sh,v 1.4.2.1 2009-08-17 17:09:59 devrim Exp $
 
 # nagios plugin that checks whether the slon daemon is running
 # if the 3rd parameter (LOGFILE) is specified then the log file is
@@ -17,10 +17,10 @@
 #
 # Author:  John Sidney-Woollett
 # Created: 26-Feb-2005
-# Copyright 2005
+# Copyright 2005-2009
 
 # check parameters are valid
-if [[ $# -lt 2 && $# -gt 3 ]]
+if [ $# -lt 2 ] || [ $# -gt 3 ]
 then
    echo "Invalid parameters need CLUSTERNAME DBNAME DBHOST [LOGFILE]"
    exit 2
