@@ -1,11 +1,12 @@
 #!/bin/bash
-# 
+# $Id: configure-replication.sh,v 1.5 2008-04-24 15:11:14 cbbrowne Exp $
 
 # Global defaults
 CLUSTER=${CLUSTER:-"slonytest"}
 NUMNODES=${NUMNODES:-"2"}
 
 # Defaults - origin node
+ORIGIN=1
 DB1=${DB1:-${PGDATABASE:-"slonytest"}}
 HOST1=${HOST1:-`hostname`}
 USER1=${USER1:-${PGUSER:-"slony"}}
@@ -35,6 +36,14 @@ HOST5=${HOST5:-"backup5.example.info"}
 USER5=${USER5:-${PGUSER:-"slony"}}
 PORT5=${PORT5:-${PGPORT:-"5432"}}
 
+
+tmpdir=`mktemp -d -t slonytest-temp.XXXXXX`
+if [ $MY_MKTEMP_IS_DECREPIT ] ; then
+       tmpdir=`mktemp -d /tmp/slonytest-temp.XXXXXX`
+fi
+mktmp=${SLONIKCONFDIR:-${tmpdir}}
+mkdir -p ${mktmp}
+
 store_path()
 {
 
@@ -77,11 +86,6 @@ echo "include <${PREAMBLE}>;" > $mktmp/store_paths.slonik
   done
 }
 
-mktmp=`mktemp -d -t slonytest-temp.XXXXXX`
-if [ $MY_MKTEMP_IS_DECREPIT ] ; then
-       mktmp=`mktemp -d /tmp/slonytest-temp.XXXXXX`
-fi
-
 PREAMBLE=${mktmp}/preamble.slonik
 
 echo "cluster name=${CLUSTER};" > $PREAMBLE
@@ -142,13 +146,13 @@ echo "create set (id=1, origin=1, comment='${CLUSTER} Tables and Sequences');" >
 tnum=1
 
 for table in `echo $TABLES`; do
-    echo "set add table (id=${tnum}, set id=1, origin=1, fully qualified name='${table}', comment='${CLUSTER} table ${table}');" >> $SETUPSET
+    echo "set add table (id=${tnum}, set id=1, origin=${ORIGIN}, fully qualified name='${table}', comment='${CLUSTER} table ${table}');" >> $SETUPSET
     tnum=`expr ${tnum} + 1`
 done
 
 snum=1
 for seq in `echo $SEQUENCES`; do
-    echo "set add sequence (id=${snum}, set id=1, origin=1, fully qualified name='${seq}', comment='${CLUSTER} sequence ${seq}');" >> $SETUPSET    
+    echo "set add sequence (id=${snum}, set id=1, origin=${ORIGIN}, fully qualified name='${seq}', comment='${CLUSTER} sequence ${seq}');" >> $SETUPSET
     snum=`expr ${snum} + 1`
 done
 
@@ -160,7 +164,7 @@ node=2
 while : ; do
     SUBFILE=$mktmp/subscribe_set_${node}.slonik
     echo "include <${PREAMBLE}>;" > $SUBFILE
-    echo "store node (id=${node}, comment='${CLUSTER} subscriber node ${node}');" >> $NODEINIT
+    echo "store node (id=${node}, comment='${CLUSTER} subscriber node ${node}', event node=${ORIGIN});" >> $NODEINIT
     echo "subscribe set (id=1, provider=1, receiver=${node}, forward=yes);" >> $SUBFILE
     if [ ${node} -ge ${NUMNODES} ]; then
       break;
